@@ -2584,7 +2584,9 @@ where
 
     fn has_leading_comment(&self, arg: &Expr) -> bool {
         if let Some(cmt) = self.comments {
-            let lo = arg.span().lo;
+            let span = arg.span();
+
+            let lo = span.lo;
 
             // see #415
             if let Some(cmt) = cmt.get_leading(lo) {
@@ -2599,6 +2601,8 @@ where
                     return true;
                 }
             }
+        } else {
+            return false;
         }
 
         match arg {
@@ -2644,6 +2648,14 @@ where
                 }
             }
 
+            Expr::Seq(e) => {
+                if let Some(e) = e.exprs.first() {
+                    if self.has_leading_comment(e) {
+                        return true;
+                    }
+                }
+            }
+
             _ => {}
         }
 
@@ -2659,11 +2671,11 @@ where
         keyword!("return");
 
         if let Some(ref arg) = n.arg {
-            let need_paren = !n.arg.span().is_dummy()
-                && n.arg
-                    .as_deref()
-                    .map(|expr| self.has_leading_comment(expr))
-                    .unwrap_or(false);
+            let need_paren = n
+                .arg
+                .as_deref()
+                .map(|expr| self.has_leading_comment(expr))
+                .unwrap_or(false);
             if need_paren {
                 punct!("(");
             } else if arg.starts_with_alpha_num() {
@@ -2855,12 +2867,19 @@ where
         keyword!("throw");
 
         {
-            if n.arg.starts_with_alpha_num() {
+            let need_paren = self.has_leading_comment(&n.arg);
+            if need_paren {
+                punct!("(");
+            } else if n.arg.starts_with_alpha_num() {
                 space!();
             } else {
                 formatting_space!();
             }
+
             emit!(n.arg);
+            if need_paren {
+                punct!(")");
+            }
         }
         semi!();
 
